@@ -28,7 +28,8 @@ def image_to_ascii_art(imgpath: str, output_file: str = "pywhatkit_asciiart.txt"
 
     # split string of chars into multiple strings of length equal to new width and create a list
     new_pixels_count = len(new_pixels)
-    ascii_image = [new_pixels[index:index + new_width] for index in range(0, new_pixels_count, new_width)]
+    ascii_image = [new_pixels[index:index + new_width]
+                   for index in range(0, new_pixels_count, new_width)]
     ascii_image = "\n".join(ascii_image)
 
     # write to a text file.
