@@ -1,13 +1,14 @@
 import smtplib
 from email.message import EmailMessage
+from email.mime.text import MIMEText
 import re
 from .exceptions import UnsupportedEmailProvider
+from typing import Union, NoReturn
 
 
 def send_mail(email_sender: str, password: str, subject: str,
-              message: str, email_receiver: str) -> None:
-
-    """Please make sure the credentials are correct"""
+              message: Union[str, MIMEText], email_receiver: str) -> NoReturn:
+    """Send an Email"""
 
     domain = re.search("(?<=@)[^.]+(?=\\.)", email_sender)
 
@@ -21,7 +22,8 @@ def send_mail(email_sender: str, password: str, subject: str,
             break
 
     if hostname is None:
-        raise UnsupportedEmailProvider(f"{domain.group()} is not supported currently!")
+        raise UnsupportedEmailProvider(
+            f"{domain.group()} is not supported currently!")
 
     with smtplib.SMTP_SSL(hostname, 465) as smtp:
         smtp.login(email_sender, password)
@@ -34,3 +36,11 @@ def send_mail(email_sender: str, password: str, subject: str,
 
         smtp.send_message(msg)
         print('Email sent Successfully!')
+
+
+def send_hmail(email_sender: str, password: str, subject: str,
+               html_code: str, email_receiver: str) -> NoReturn:
+    """Send an Email with HTML code"""
+
+    message = MIMEText(html_code, "html")
+    send_mail(email_sender, password, subject, message, email_receiver)
