@@ -4,9 +4,10 @@ import pyautogui as pg
 import wikipedia
 import requests
 import os
-import smtplib
 from urllib.parse import quote
 from .exceptions import *
+from typing import NoReturn, Optional
+from PIL import ImageGrab
 
 last = time.time()
 pg.FAILSAFE = False
@@ -19,45 +20,57 @@ def print_sleep_time() -> str:
     return sleep_time
 
 
-def check_window() -> None:
+def take_screenshot(file_name: str = 'pywhatkit_screenshot') -> NoReturn:
+    """Take Screenshot, you can change the filename as per your Wish"""
+    screen = ImageGrab.grab()
+    screen.show()
+    screen.save(f'{file_name}.png')
+
+
+def check_window() -> NoReturn:
+    """Check if the browser Window is maximized or not"""
     web.open("https://www.google.com")
-    pg.alert("If the browser's window is not maximised,\nMaximise and then close it if you want,\nor sendwhatmsg() "
+    pg.alert("If the browser's window is not maximized,\nMaximise and then close it if you want,\nor sendwhatmsg() "
              "function will not work", "Pywhatkit")
 
-def sendwhatmsg_instantly(phone_no, message, wait_time=20, browser=None) -> None:
-    '''Sends whatsapp message to a particulal number instantly
-Phone number should be in string format not int
-***This function will not work if the browser's window is minimised,
-first check it by calling 'check_window()' function'''
+
+def sendwhatmsg_instantly(phone_no: str, message: str, wait_time: int = 20,
+                          browser: str = None, tab_close: bool = False) -> NoReturn:
+    """Send WhatsApp Message Instantly"""
 
     if browser and browser.lower() not in ["chrome", "firefox", "brave", "opera"]:
         raise InvalidBrowserName("Browser name can be firefox, chrome, brave, opera")
 
     if "+" not in phone_no:
         raise CountryCodeException("Country code missing from phone_no")
-    
-    parsedMessage = quote(message)
-    web.open('https://web.whatsapp.com/send?phone='+phone_no+'&text='+parsedMessage)
+
+    parsed_message = quote(message)
+    web.open('https://web.whatsapp.com/send?phone=' + phone_no + '&text=' + parsed_message)
     time.sleep(2)
-    width,height = pg.size()
+    width, height = pg.size()
     if browser:
         whats = pg.getWindowsWithTitle(browser)[0]
         whats.maximize()
         whats.activate()
-    pg.click(width/2,height/2)
-    time.sleep(wait_time-2)
+    pg.click(width / 2, height / 2)
+    time.sleep(wait_time - 2)
     pg.press('enter')
+    if tab_close:
+        close_tab()
+
 
-    
 def sendwhatmsg(phone_no: str, message: str, time_hour: int, time_min: int, wait_time: int = 20,
-                print_wait_time: bool = True, browser: str = None) -> None:
-    """Sends a message at a specific time
-    Phone number should be given as a string
-    If the browser Window is not maximized this function won't work
-    Use check_window to check this"""
+                print_wait_time: bool = True, browser: str = None, tab_close: bool = False) -> NoReturn:
+    """Sends a WhatsApp Message"""
+    # Phone number should be given as a string
+    # If the browser Window is not maximized this function won't work
+    # Use check_window to check this
 
-    if browser and browser.lower() not in ["chrome", "firefox", "brave", "opera"]:
-        raise InvalidBrowserName("Browser name can be firefox, chrome, brave, opera")
+    if browser is None:
+        pass
+    elif browser.lower() not in ["chrome", "firefox", "brave", "opera"]:
+        raise InvalidBrowserName(
+            "Browser name can be firefox, chrome, brave, opera")
 
     global sleep_time
     if "+" not in phone_no:
@@ -86,12 +99,14 @@ def sendwhatmsg(phone_no: str, message: str, time_hour: int, time_min: int, wait
         lefttm = 86400 + lefttm
 
     if lefttm < wait_time:
-        raise CallTimeException("Call time must be greater than wait_time as web.whatsapp.com takes some time to load")
+        raise CallTimeException(
+            "Call time must be greater than wait_time as web.whatsapp.com takes some time to load")
 
     date = "%s:%s:%s" % (curr.tm_mday, curr.tm_mon, curr.tm_year)
     time_write = "%s:%s" % (timehr, time_min)
     file = open("pywhatkit_dbs.txt", "a", encoding='utf-8')
-    file.write("Date: %s\nTime: %s\nPhone number: %s\nMessage: %s" % (date, time_write, phone_no, message))
+    file.write("Date: %s\nTime: %s\nPhone number: %s\nMessage: %s" %
+               (date, time_write, phone_no, message))
     file.write("\n--------------------\n")
     file.close()
     sleep_time = lefttm - wait_time
@@ -99,8 +114,9 @@ def sendwhatmsg(phone_no: str, message: str, time_hour: int, time_min: int, wait
         print(
             f"In {print_sleep_time()} seconds web.whatsapp.com will open and after {wait_time} seconds message will be delivered")
     time.sleep(sleep_time)
-    parsedMessage = quote(message)
-    web.open('https://web.whatsapp.com/send?phone=' + phone_no + '&text=' + parsedMessage)
+    parsed_message = quote(message)
+    web.open('https://web.whatsapp.com/send?phone=' +
+             phone_no + '&text=' + parsed_message)
     time.sleep(2)
     width, height = pg.size()
     if browser:
@@ -110,12 +126,15 @@ def sendwhatmsg(phone_no: str, message: str, time_hour: int, time_min: int, wait
     pg.click(width / 2, height / 2)
     time.sleep(wait_time - 2)
     pg.press('enter')
+    if tab_close:
+        close_tab()
 
 
 def sendwhatmsg_to_group(group_id: str, message: str, time_hour: int, time_min: int, wait_time: int = 20,
-                         print_wait_time: bool = True) -> None:
-    """Group ID is in the group's invite link
-    https://chat.whatsapp.com/AB123CDEFGHijklmn, here AB123CDEFGHijklmn is group ID"""
+                         print_wait_time: bool = True, tab_close: bool = False) -> NoReturn:
+    """Send WhatsApp Message to a Group"""
+    # Group ID is in the group's invite link
+    # https://chat.whatsapp.com/AB123CDEFGHijklmn, here AB123CDEFGHijklmn is group ID
     if time_hour not in range(0, 25) or time_min not in range(0, 60):
         print("Invalid time format")
 
@@ -140,12 +159,14 @@ def sendwhatmsg_to_group(group_id: str, message: str, time_hour: int, time_min:
         lefttm = 86400 + lefttm
 
     if lefttm < wait_time:
-        raise CallTimeException("Call time must be greater than wait_time as web.whatsapp.com takes some time to load")
+        raise CallTimeException(
+            "Call time must be greater than wait_time as web.whatsapp.com takes some time to load")
 
     date = "%s:%s:%s" % (curr.tm_mday, curr.tm_mon, curr.tm_year)
     time_write = "%s:%s" % (timehr, time_min)
     file = open("pywhatkit_dbs.txt", "a", encoding='utf-8')
-    file.write("Date: %s\nTime: %s\nGroup_id: %s\nMessage: %s" % (date, time_write, group_id, message))
+    file.write("Date: %s\nTime: %s\nGroup_id: %s\nMessage: %s" %
+               (date, time_write, group_id, message))
     file.write("\n--------------------\n")
     file.close()
     sleeptm = lefttm - wait_time
@@ -162,22 +183,36 @@ def sendwhatmsg_to_group(group_id: str, message: str, time_hour: int, time_min:
     time.sleep(wait_time - 2)
     pg.click(width / 2, height - height / 10)
     pg.typewrite(message + "\n")
+    if tab_close:
+        close_tab()
 
 
-def info(topic: str, lines: int = 3) -> None:
+def info(topic: str, lines: int = 3, return_value: bool = False) -> Optional[str]:
     """Gives information on the topic"""
     spe = wikipedia.summary(topic, sentences=lines)
     print(spe)
+    if return_value:
+        return spe
 
 
-def playonyt(topic: str, use_api: bool = False) -> str:
-    """use_api uses the pywhatkit playonyt API to get the url for the video
-    Only to be used if the function is not working properly on its own"""
+def close_tab(wait_time: int = 2) -> NoReturn:
+    """Closes the Currently Opened Browser Tab"""
+    time.sleep(wait_time)
+    pg.hotkey("ctrl", "w")
+    pg.press("enter")
 
-    if use_api:
-        response = requests.get(f"https://pywhatkit.herokuapp.com/playonyt?topic={topic}")
-        web.open(response.content.decode('ascii'))
-        return response.text
+
+def playonyt(topic: str, use_api: bool = False, open_video: bool = True) -> str:
+    """Play a YouTube Video"""
+    # use_api uses the pywhatkit playonyt API to get the url for the video
+    # use the api only if the function is not working properly on its own
+
+    if use_api is True:
+        response = requests.get(
+            f"https://pywhatkit.herokuapp.com/playonyt?topic={topic}")
+        if open_video:
+            web.open(response.content.decode('ascii'))
+        return response.content.decode('ascii')
     else:
         url = 'https://www.youtube.com/results?q=' + topic
         count = 0
@@ -193,11 +228,22 @@ def playonyt(topic: str, use_api: bool = False) -> str:
             raise Exception("No video found.")
 
         # print("Videos found, opening most recent video")
-        web.open("https://www.youtube.com" + lst[count - 5])
+        if open_video:
+            web.open("https://www.youtube.com" + lst[count - 5])
         return "https://www.youtube.com" + lst[count - 5]
 
 
-def search(topic: str) -> None:
+def open_web() -> bool:
+    """Opens WhatsApp Web"""
+    try:
+        web.open("https://web.whatsapp.com")
+    except web.Error:
+        return False
+    else:
+        return True
+
+
+def search(topic: str) -> NoReturn:
     """Searches about the topic on Google"""
     link = 'https://www.google.com/search?q={}'.format(topic)
     web.open(link)
@@ -208,10 +254,12 @@ try:
     current = time.time()
     tyme = current - last
 except Exception:
-    raise InternetException("NO INTERNET - Pywhatkit needs active internet connection")
+    raise InternetException(
+        "NO INTERNET - Pywhatkit needs active internet connection")
 
 if tyme >= 5:
-    raise Warning("INTERNET IS SLOW, extraction of information might take longer time")
+    raise Warning(
+        "INTERNET IS SLOW, extraction of information might take longer time")
 
 
 try:
