@@ -1,12 +1,14 @@
 import platform
 import os
+from typing import NoReturn
 
 osname = platform.system()
 
 
-def shutdown(time: int = 20) -> None:
-    """For Windows, time should be given in seconds
-    For MacOS and Linux based distributions, time should be given in minutes"""
+def shutdown(time: int = 20) -> NoReturn:
+    """Shutdowns the machine in a given time"""
+    # For Windows, time should be given in seconds
+    # For MacOS and Linux based distributions, time should be given in minutes
 
     if "window" in osname.lower():
         cont = "shutdown -s -t %s" % time
@@ -21,10 +23,11 @@ def shutdown(time: int = 20) -> None:
         os.system(cont)
 
     else:
-        raise Warning("This function is for Windows, Mac and Linux users only, can't execute on %s" % osname)
+        raise Warning(
+            "This function is for Windows, Mac and Linux users only, can't execute on %s" % osname)
 
 
-def cancelShutdown() -> None:
+def cancel_shutdown() -> NoReturn:
     """Will cancel the scheduled shutdown"""
     if "window" in osname.lower():
         cont = "shutdown /a"
@@ -42,4 +45,5 @@ def cancelShutdown() -> None:
         print("Shutdown has been Cancelled!")
 
     else:
-        raise Warning("This function is for Windows and Linux only, can't execute on: %s" % osname)
+        raise Warning(
+            "This function is for Windows and Linux only, can't execute on: %s" % osname)
